@@ -122,7 +122,7 @@ VR.Models.Proc = Backbone.Model.extend({
 
     restart: function() { this.doAction('restart'); },
 
-    isRunning: function() {return this.get('statename') == 'RUNNING';},
+    isRunning: function() {return this.get('statename') === 'RUNNING';},
 
     isStopped: function() {
       var state = this.get('statename');
@@ -413,9 +413,6 @@ VR.Models.App = VR.Models.Tasty.extend({
 
     onSwarmsEvent: function(event, model, collection, options) {
       this.trigger.apply(this, arguments);
-      if (event === 'removeproc') {
-        console.log(this.swarms);
-      }
     }
 });
 
@@ -550,6 +547,7 @@ VR.Views.Proc = Backbone.View.extend({
 
 
 VR.Views.ProcModal = Backbone.View.extend({
+    el: '<div class="modalwrap" tabindex="-1"></div>',
     initialize: function(proc) {
       this.proc = proc;
       this.fresh = true;
@@ -761,6 +759,7 @@ VR.Views.Swarm = Backbone.View.extend({
 });
 
 VR.Views.SwarmModal = Backbone.View.extend({
+    el: '<div class="modalwrap" tabindex="-1"></div>',
     initialize: function(swarm, template) {
       this.swarm = swarm;
       this.current_state = '';
@@ -840,10 +839,10 @@ VR.Views.SwarmModal = Backbone.View.extend({
       this.swarm.restartAll();
     },
     onSwarmEvent: function(event, model, collection, options) {
-      console.log(arguments);
+      //console.log(arguments);
     },
     onProcEvent: function(event, model, collection, options) {
-      console.log(arguments);
+      //console.log(arguments);
     }
 
 });
@@ -895,6 +894,7 @@ VR.Views.App = Backbone.View.extend({
 });
 
 VR.Views.AppModal = Backbone.View.extend({
+    el: '<div class="modalwrap" tabindex="-1"></div>',
     initialize: function(app, template) {
       this.app = app;
       this.template = template || VR.Templates.AppModal;
